<?php
$lib_dir = trailingslashit( str_replace( '\\', '/', get_template_directory() . '/lib/' ) );

if( !defined('FLASHMART_DIR') ){
	define( 'FLASHMART_DIR', $lib_dir );
}

if( !defined('FLASHMART_URL') ){
	define( 'FLASHMART_URL', trailingslashit( get_template_directory_uri() ) . 'lib' );
}

if (!isset($content_width)) { $content_width = 940; }

define("FLASHMART_PRODUCT_TYPE","product");
define("FLASHMART_PRODUCT_DETAIL_TYPE","product_detail");

if ( !defined('SWG_THEME') ){
	define( 'SWG_THEME', 'flashmart_theme' );
}

require_once( get_template_directory().'/lib/options.php' );

if( class_exists( 'SWG_Options' ) ) :
	function flashmart_Options_Setup(){
		global $swg_options, $options, $options_args;

		$options = array();
		$options[] = array(
			'title' => esc_html__('General', 'flashmart'),
			'desc' => wp_kses( __('<p class="description">The theme allows to build your own styles right out of the backend without any coding knowledge. Upload new logo and favicon or get their URL.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
			//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
			//You dont have to though, leave it flashmart for default.
			'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_019_cogwheel.png',
			//Lets leave this as a flashmart section, no options just some intro text set above.
			'fields' => array(	

				array(
					'id' => 'sitelogo',
					'type' => 'upload',
					'title' => esc_html__('Logo Image', 'flashmart'),
					'sub_desc' => esc_html__( 'Use the Upload button to upload the new logo and get URL of the logo', 'flashmart' ),
					'std' => get_template_directory_uri().'/assets/img/logo-default.png'
				),

				array(
					'id' => 'favicon',
					'type' => 'upload',
					'title' => esc_html__('Favicon', 'flashmart'),
					'sub_desc' => esc_html__( 'Use the Upload button to upload the custom favicon', 'flashmart' ),
					'std' => ''
				),

				array(
					'id' => 'tax_select',
					'type' => 'multi_select_taxonomy',
					'title' => esc_html__('Select Taxonomy', 'flashmart'),
					'sub_desc' => esc_html__( 'Select taxonomy to show custom term metabox', 'flashmart' ),
				),

				array(
					'id' => 'title_length',
					'type' => 'text',
					'title' => esc_html__('Title Length Of Item Listing Page', 'flashmart'),
					'sub_desc' => esc_html__( 'Choose title length if you want to trim word, leave 0 to not trim word', 'flashmart' ),
					'std' => 0
				),

				array(
					'id' => 'page_404',
					'type' => 'pages_select',
					'title' => esc_html__('404 Page Content', 'flashmart'),
					'sub_desc' => esc_html__('Select page 404 content', 'flashmart'),
					'std' => ''
				),
			)		
		);

		$options[] = array(
			'title' => esc_html__('Schemes', 'flashmart'),
			'desc' => wp_kses( __('<p class="description">Custom color scheme for theme. Unlimited color that you can choose.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
			//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
			//You dont have to though, leave it flashmart for default.
			'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_163_iphone.png',
			//Lets leave this as a flashmart section, no options just some intro text set above.
			'fields' => array(
				array(
					'id' => 'scheme',
					'type' => 'radio_img',
					'title' => esc_html__('Color Scheme', 'flashmart'),
					'sub_desc' => esc_html__( 'Select one of 2 predefined schemes', 'flashmart' ),
					'desc' => '',
					'options' => array(
						'default' => array('title' => 'Default', 'img' => get_template_directory_uri().'/assets/img/default.png'),
						'yellow' => array('title' => 'Yellow', 'img' => get_template_directory_uri().'/assets/img/yellow.png'),
						'blue' => array('title' => 'Blue', 'img' => get_template_directory_uri().'/assets/img/blue.png'),
						'green' => array('title' => 'Green', 'img' => get_template_directory_uri().'/assets/img/green.png'),
						'green2' => array('title' => 'Green2', 'img' => get_template_directory_uri().'/assets/img/green2.png'),
						'pink' => array('title' => 'Pink', 'img' => get_template_directory_uri().'/assets/img/pink.png'),
						'brown' => array('title' => 'Brown', 'img' => get_template_directory_uri().'/assets/img/brown.png'),
						), //Must provide key => value(array:title|img) pairs for radio options
					'std' => 'default'
				),
				
				array(
					'id' => 'custom_color',
					'title' => esc_html__( 'Enable Custom Color', 'flashmart' ),
					'type' => 'checkbox',
					'sub_desc' => esc_html__( 'Check this field to enable custom color and when you update your theme, custom color will not lose.', 'flashmart' ),
					'desc' => '',
					'std' => '0'
				),

				array(
					'id' => 'developer_mode',
					'title' => esc_html__( 'Developer Mode', 'flashmart' ),
					'type' => 'checkbox',
					'sub_desc' => esc_html__( 'Turn on/off compile less to css and custom color', 'flashmart' ),
					'desc' => '',
					'std' => '0'
				),
				
				array(
					'id' => 'scheme_color',
					'type' => 'color',
					'title' => esc_html__('Color', 'flashmart'),
					'sub_desc' => esc_html__('Select main custom color.', 'flashmart'),
					'std' => ''
				),

			)
		);

		$options[] = array(
			'title' => esc_html__('Layout', 'flashmart'),
			'desc' => wp_kses( __('<p class="description">WpThemeGo Framework comes with a layout setting that allows you to build any number of stunning layouts and apply theme to your entries.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
			//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
			//You dont have to though, leave it flashmart for default.
			'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_319_sort.png',
			//Lets leave this as a flashmart section, no options just some intro text set above.
			'fields' => array(
				array(
					'id' => 'layout',
					'type' => 'select',
					'title' => esc_html__('Box Layout', 'flashmart'),
					'sub_desc' => esc_html__( 'Select Layout Box or Wide, Sidebar', 'flashmart' ),
					'options' => array(
						'full' => esc_html__( 'Wide', 'flashmart' ),
						'wide' => esc_html__( 'Wide 1400', 'flashmart' ),
						'boxed' => esc_html__( 'Boxed', 'flashmart' ),
					),
					'std' => 'full'
				),
				
				array(
					'id' => 'layout_width',
					'type' => 'number',
					'title' => esc_html__('Layout Width', 'flashmart'),
					'sub_desc' => esc_html__( 'Select Layout width content', 'flashmart' ),				
					'std' => 1170
				),
				
				array(
					'id' => 'bg_box_img',
					'type' => 'upload',
					'title' => esc_html__('Background Box Image', 'flashmart'),
					'sub_desc' => '',
					'std' => ''
				),
				array(
					'id' => 'sidebar_left_expand',
					'type' => 'select',
					'title' => esc_html__('Left Sidebar Expand', 'flashmart'),
					'options' => array(
						'2' => '2/12',
						'3' => '3/12',
						'4' => '4/12',
						'5' => '5/12', 
						'6' => '6/12',
						'7' => '7/12',
						'8' => '8/12',
						'9' => '9/12',
						'10' => '10/12',
						'11' => '11/12',
						'12' => '12/12'
					),
					'std' => '3',
					'sub_desc' => esc_html__( 'Select width of left sidebar.', 'flashmart' ),
				),

				array(
					'id' => 'sidebar_right_expand',
					'type' => 'select',
					'title' => esc_html__('Right Sidebar Expand', 'flashmart'),
					'options' => array(
						'2' => '2/12',
						'3' => '3/12',
						'4' => '4/12',
						'5' => '5/12',
						'6' => '6/12',
						'7' => '7/12',
						'8' => '8/12',
						'9' => '9/12',
						'10' => '10/12',
						'11' => '11/12',
						'12' => '12/12'
					),
					'std' => '3',
					'sub_desc' => esc_html__( 'Select width of right sidebar medium desktop.', 'flashmart' ),
				),
				array(
					'id' => 'sidebar_left_expand_md',
					'type' => 'select',
					'title' => esc_html__('Left Sidebar Medium Desktop Expand', 'flashmart'),
					'options' => array(
						'2' => '2/12',
						'3' => '3/12',
						'4' => '4/12',
						'5' => '5/12',
						'6' => '6/12',
						'7' => '7/12',
						'8' => '8/12',
						'9' => '9/12',
						'10' => '10/12',
						'11' => '11/12',
						'12' => '12/12'
					),
					'std' => '4',
					'sub_desc' => esc_html__( 'Select width of left sidebar medium desktop.', 'flashmart' ),
				),
				array(
					'id' => 'sidebar_right_expand_md',
					'type' => 'select',
					'title' => esc_html__('Right Sidebar Medium Desktop Expand', 'flashmart'),
					'options' => array(
						'2' => '2/12',
						'3' => '3/12',
						'4' => '4/12',
						'5' => '5/12',
						'6' => '6/12',
						'7' => '7/12',
						'8' => '8/12',
						'9' => '9/12',
						'10' => '10/12',
						'11' => '11/12',
						'12' => '12/12'
					),
					'std' => '4',
					'sub_desc' => esc_html__( 'Select width of right sidebar.', 'flashmart' ),
				),
				array(
					'id' => 'sidebar_left_expand_sm',
					'type' => 'select',
					'title' => esc_html__('Left Sidebar Tablet Expand', 'flashmart'),
					'options' => array(
						'2' => '2/12',
						'3' => '3/12',
						'4' => '4/12',
						'5' => '5/12',
						'6' => '6/12',
						'7' => '7/12',
						'8' => '8/12',
						'9' => '9/12',
						'10' => '10/12',
						'11' => '11/12',
						'12' => '12/12'
					),
					'std' => '4',
					'sub_desc' => esc_html__( 'Select width of left sidebar tablet.', 'flashmart' ),
				),
				array(
					'id' => 'sidebar_right_expand_sm',
					'type' => 'select',
					'title' => esc_html__('Right Sidebar Tablet Expand', 'flashmart'),
					'options' => array(
						'2' => '2/12',
						'3' => '3/12',
						'4' => '4/12',
						'5' => '5/12',
						'6' => '6/12',
						'7' => '7/12',
						'8' => '8/12',
						'9' => '9/12',
						'10' => '10/12',
						'11' => '11/12',
						'12' => '12/12'
					),
					'std' => '4',
					'sub_desc' => esc_html__( 'Select width of right sidebar tablet.', 'flashmart' ),
				),				
			)
		);

$options[] = array(
	'title' => esc_html__('Mobile Layout', 'flashmart'),
	'desc' => wp_kses( __('<p class="description">WpThemeGo Framework comes with a mobile setting home page layout.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
			//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
			//You dont have to though, leave it flashmart for default.
	'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_163_iphone.png',
			//Lets leave this as a flashmart section, no options just some intro text set above.
	'fields' => array(
		array(
			'id' => 'mobile_enable',
			'type' => 'checkbox',
			'title' => esc_html__('Enable Mobile Layout', 'flashmart'),
			'sub_desc' => '',
			'desc' => '',
							'std' => '1'// 1 = on | 0 = off
						),

		array(
			'id' => 'mobile_logo',
			'type' => 'upload',
			'title' => esc_html__('Logo Mobile Image', 'flashmart'),
			'sub_desc' => esc_html__( 'Use the Upload button to upload the new mobile logo', 'flashmart' ),
			'std' => get_template_directory_uri().'/assets/img/logo-mobile.png'
		),

		array(
			'id' => 'mobile_logo_account',
			'type' => 'upload',
			'title' => esc_html__('Logo Mobile My Account Page', 'flashmart'),
			'sub_desc' => esc_html__( 'Use the Upload button to upload the new mobile logo in my account page', 'flashmart' ),
			'std' => get_template_directory_uri().'/assets/img/icon-myaccount.png'
		),

		array(
			'id' => 'sticky_mobile',
			'type' => 'checkbox',
			'title' => esc_html__('Sticky Mobile', 'flashmart'),
			'sub_desc' => '',
			'desc' => '',
							'std' => '0'// 1 = on | 0 = off
						),

		array(
			'id' => 'mobile_content',
			'type' => 'pages_select',
			'title' => esc_html__('Mobile Layout Content', 'flashmart'),
			'sub_desc' => esc_html__('Select content index for this mobile layout', 'flashmart'),
			'std' => ''
		),

		array(
			'id' => 'mobile_header_style',
			'type' => 'select',
			'title' => esc_html__('Header Mobile Style', 'flashmart'),
			'sub_desc' => esc_html__('Select header mobile style', 'flashmart'),
			'options' => array(
				'mstyle1'  => esc_html__( 'Style 1', 'flashmart' ),
			),
			'std' => 'style1'
		),

		array(
			'id' => 'mobile_footer_style',
			'type' => 'select',
			'title' => esc_html__('Footer Mobile Style', 'flashmart'),
			'sub_desc' => esc_html__('Select footer mobile style', 'flashmart'),
			'options' => array(
				'mstyle1'  => esc_html__( 'Style 1', 'flashmart' ),
			),
			'std' => 'style1'
		),

		array(
			'id' => 'mobile_addcart',
			'type' => 'checkbox',
			'title' => esc_html__('Enable Add To Cart Button', 'flashmart'),
			'sub_desc' => esc_html__( 'Enable Add To Cart Button on product listing', 'flashmart' ),
			'desc' => '',
						'std' => '0'// 1 = on | 0 = off
					),

		array(
			'id' => 'mobile_header_inside',
			'type' => 'checkbox',
			'title' => esc_html__('Enable Header Other Pages', 'flashmart'),
			'sub_desc' => esc_html__( 'Enable header in other pages which are different with homepage', 'flashmart' ),
			'desc' => '',
						'std' => '0'// 1 = on | 0 = off
					),

		array(
			'id' => 'mobile_jquery',
			'type' => 'checkbox',
			'title' => esc_html__('Include Jquery Revolution', 'flashmart'),
			'sub_desc' => esc_html__( 'Enable jquery revolution slider on mobile layout.', 'flashmart' ),
			'desc' => '',
						'std' => '0'// 1 = on | 0 = off
					),
	)
);

$options[] = array(
	'title' => esc_html__('Header', 'flashmart'),
	'desc' => wp_kses( __('<p class="description">WpThemeGo Framework comes with a header and footer setting that allows you to build style header.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
			//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
			//You dont have to though, leave it flashmart for default.
	'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_336_read_it_later.png',
			//Lets leave this as a flashmart section, no options just some intro text set above.
	'fields' => array(
		array(
			'id' => 'header_style',
			'type' => 'select',
			'title' => esc_html__('Header Style', 'flashmart'),
			'sub_desc' => esc_html__('Select Header style', 'flashmart'),
			'options' => array(
				'style1'  => esc_html__( 'Header Style 1', 'flashmart' ),
			),
			'std' => 'style1'
		),

		array(
			'id' => 'disable_search',
			'title' => esc_html__( 'Disable Search', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => esc_html__( 'Check this to disable search on header', 'flashmart' ),
			'desc' => '',
			'std' => '0'
		),

		array(
			'id' => 'disable_cart',
			'title' => esc_html__( 'Disable Cart', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => esc_html__( 'Check this to disable cart on header', 'flashmart' ),
			'desc' => '',
			'std' => '0'
		),

		array(
			'id' => 'disable_boxsidebar',
			'title' => esc_html__( 'Disable Box Sdebar On Pages', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => esc_html__( 'Check this to disable box sidebar on pages', 'flashmart' ),
			'desc' => '',
			'std' => '0'
		),

	)
);
$options[] = array(
	'title' => esc_html__('Navbar Options', 'flashmart'),
	'desc' => wp_kses( __('<p class="description">If you got a big site with a lot of sub menus we recommend using a mega menu. Just select the dropbox to display a menu as mega menu or dropdown menu.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
			//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
			//You dont have to though, leave it flashmart for default.
	'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_157_show_lines.png',
			//Lets leave this as a flashmart section, no options just some intro text set above.
	'fields' => array(
		array(
			'id' => 'info_typon1',
			'type' => 'info',
			'title' => esc_html__( 'Navbar Menu General Config', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'menu_type',
			'type' => 'select',
			'title' => esc_html__('Menu Type', 'flashmart'),
			'options' => array( 
				'dropdown' => esc_html__( 'Dropdown Menu', 'flashmart' ), 
				'mega' => esc_html__( 'Mega Menu', 'flashmart' ) 
			),
			'std' => 'mega'
		),	

		array(
			'id' => 'menu_location',
			'type' => 'menu_location_multi_select',
			'title' => esc_html__('Mega Menu Location', 'flashmart'),
			'sub_desc' => esc_html__( 'Select theme location to active mega menu.', 'flashmart' ),
			'std' => 'primary_menu'
		),		

		array(
			'id' => 'more_menu',
			'type' => 'checkbox',
			'title' => esc_html__('Active More Menu', 'flashmart'),
			'sub_desc' => esc_html__('Active more menu if your primary menu is too long', 'flashmart'),
			'desc' => '',
						'std' => '0'// 1 = on | 0 = off
					),

		array(
			'id' => 'menu_event',
			'type' => 'select',
			'title' => esc_html__('Menu Event', 'flashmart'),
			'options' => array( 
				'' 		=> esc_html__( 'Hover Event', 'flashmart' ), 
				'click' => esc_html__( 'Click Event', 'flashmart' ) 
			),
			'std' => ''
		),

		array(
			'id' => 'menu_number_item',
			'type' => 'text',
			'title' => esc_html__( 'Number Item Vertical', 'flashmart' ),
			'sub_desc' => esc_html__( 'Number item vertical to show', 'flashmart' ),
			'std' => 8
		),	

		array(
			'id' => 'menu_title_text',
			'type' => 'text',
			'title' => esc_html__('Vertical Title Text', 'flashmart'),
			'sub_desc' => esc_html__( 'Change title text on vertical menu', 'flashmart' ),
			'std' => ''
		),

		array(
			'id' => 'menu_more_text',
			'type' => 'text',
			'title' => esc_html__('Vertical More Text', 'flashmart'),
			'sub_desc' => esc_html__( 'Change more text on vertical menu', 'flashmart' ),
			'std' => ''
		),
		
		array(
			'id' => 'menu_less_text',
			'type' => 'text',
			'title' => esc_html__('Vertical Less Text', 'flashmart'),
			'sub_desc' => esc_html__( 'Change less text on vertical menu', 'flashmart' ),
			'std' => ''
		),

		array(
			'id' => 'info_typon2',
			'type' => 'info',
			'title' => esc_html__( 'Responsive Menu Config', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'mobile_menu',
			'type' => 'menu_location_multi_select',
			'title' => esc_html__('Mobile & Responsive Menu Location', 'flashmart'),
			'sub_desc' => esc_html__( 'Select theme location to active mobile menu.', 'flashmart' ),
			'std' => 'primary_menu'
		),

		array(
			'id' => 'mobile_menu_title',
			'type' => 'text',
			'title' => esc_html__('Mobile Menu Title', 'flashmart'),
			'sub_desc' => esc_html__( 'Change title heading of menu responsive. If there are many menu, each title separated by commas.', 'flashmart' ),
			'std' => ''
		),

	)
);
$options[] = array(
	'title' => esc_html__('Blog Options', 'flashmart'),
	'desc' => wp_kses( __('<p class="description">Select layout in blog listing page.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
		//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
		//You dont have to though, leave it flashmart for default.
	'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_071_book.png',
		//Lets leave this as a flashmart section, no options just some intro text set above.
	'fields' => array(
		array(
			'id' => 'sidebar_blog',
			'type' => 'select',
			'title' => esc_html__('Sidebar Blog Layout', 'flashmart'),
			'options' => array(
				'full' 	=> esc_html__( 'Full Layout', 'flashmart' ),		
				'left'	=> esc_html__( 'Left Sidebar', 'flashmart' ),
				'right' => esc_html__( 'Right Sidebar', 'flashmart' ),
			),
			'std' => 'left',
			'sub_desc' => esc_html__( 'Select style sidebar blog', 'flashmart' ),
		),
		array(
			'id' => 'blog_layout',
			'type' => 'select',
			'title' => esc_html__('Layout blog', 'flashmart'),
			'options' => array(
				'list'	=>  esc_html__( 'List Layout', 'flashmart' ),
				'list2'	=>  esc_html__( 'List Layout2', 'flashmart' ),
				'grid' 	=>  esc_html__( 'Grid Layout', 'flashmart' )								
			),
			'std' => 'list',
			'sub_desc' => esc_html__( 'Select style layout blog', 'flashmart' ),
		),
		array(
			'id' => 'blog_column',
			'type' => 'select',
			'title' => esc_html__('Blog column', 'flashmart'),
			'options' => array(								
				'2' =>  esc_html__( '2 Columns', 'flashmart' ),
				'3' =>  esc_html__( '3 Columns', 'flashmart' ),
				'4' =>  esc_html__( '4 Columns', 'flashmart' )								
			),
			'std' => '2',
			'sub_desc' => esc_html__( 'Select style number column blog', 'flashmart' ),
		),
	)
);	
$options[] = array(
	'title' => esc_html__('Product Options', 'flashmart'),
	'desc' => wp_kses( __('<p class="description">Select layout in product listing page.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
		//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
		//You dont have to though, leave it flashmart for default.
	'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_202_shopping_cart.png',
		//Lets leave this as a flashmart section, no options just some intro text set above.
	'fields' => array(
		array(
			'id' => 'info_typo1',
			'type' => 'info',
			'title' => esc_html__( 'Product Categories Config', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'product_colcat_large',
			'type' => 'select',
			'title' => esc_html__('Product Category Listing column Desktop', 'flashmart'),
			'options' => array(
				'2' => '2',
				'3' => '3',
				'4' => '4',
				'5' => '5',
				'6' => '6',							
			),
			'std' => '4',
			'sub_desc' => esc_html__( 'Select number of column on Desktop Screen', 'flashmart' ),
		),

		array(
			'id' => 'product_colcat_medium',
			'type' => 'select',
			'title' => esc_html__('Product Listing Category column Medium Desktop', 'flashmart'),
			'options' => array(
				'2' => '2',
				'3' => '3',
				'4' => '4',	
				'5' => '5',
				'6' => '6',
			),
			'std' => '3',
			'sub_desc' => esc_html__( 'Select number of column on Medium Desktop Screen', 'flashmart' ),
		),

		array(
			'id' => 'product_colcat_sm',
			'type' => 'select',
			'title' => esc_html__('Product Listing Category column Tablet', 'flashmart'),
			'options' => array(
				'2' => '2',
				'3' => '3',
				'4' => '4',	
				'5' => '5',
				'6' => '6'
			),
			'std' => '2',
			'sub_desc' => esc_html__( 'Select number of column on Tablet Screen', 'flashmart' ),
		),

		array(
			'id' => 'info_typo1',
			'type' => 'info',
			'title' => esc_html__( 'Product General Config', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'product_loadmore',
			'title' => esc_html__( 'Enable load more product listing', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off load more in product listing', 'flashmart' ),
			'std' => '1'
			),
			
		array(
			'id' => 'product_loadmore_style',
			'title' => esc_html__( 'Select style load more ajax', 'flashmart' ),
			'type' => 'select',
			'options' => array(
				'0' => esc_html__( 'Click', 'flashmart' ),
				'1' => esc_html__( 'Scroll', 'flashmart' )					
				),
			'std' => '0',
			'sub_desc' => esc_html__( 'Select style for ajax load more in product listing', 'flashmart' ),
			),
		
		array(
			'id' => 'layout_product',
			'title' => esc_html__( 'Select Layout List/Grid For Product Listing', 'flashmart' ),
			'type' => 'select',
			'sub_desc' => '',
			'options' => array(
				'' 			=> esc_html__( 'Default', 'flashmart' ),
				'list' 	=> esc_html__( 'Layout List', 'flashmart' ),
				'grid' 	=> esc_html__( 'Layout Grid', 'flashmart' ),
				),
			'std' => '',
			),
		
		array(
			'id' => 'product_categories',
			'title' => esc_html__( 'Shop Categories', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off shop categories breadcumb', 'flashmart' ),
			'std' => '1'
		),

		array(
			'id' => 'product_banner',
			'title' => esc_html__( 'Select Banner', 'flashmart' ),
			'type' => 'select',
			'sub_desc' => '',
			'options' => array(
				'' 			=> esc_html__( 'Use Banner', 'flashmart' ),
				'listing' 	=> esc_html__( 'Use Category Product Image', 'flashmart' ),
			),
			'std' => '',
		),

		array(
			'id' => 'product_listing_banner',
			'type' => 'upload',
			'title' => esc_html__('Listing Banner Product', 'flashmart'),
			'sub_desc' => esc_html__( 'Use the Upload button to upload banner product listing', 'flashmart' ),
			'std' => get_template_directory_uri().'/assets/img/listing-banner.jpg'
		),

		array(
				'id' => 'link_banner_shop',
				'type' => 'text',
				'title' => esc_html__('Link Of Banner Product', 'flashmart'),
				'sub_desc' => esc_html__( 'Use the link for the banner product listing', 'flashmart' ),
				'std' => '',
				),
		
		array(
			'id' => 'product_col_large',
			'type' => 'select',
			'title' => esc_html__('Product Listing column Desktop', 'flashmart'),
			'options' => array(
				'2' => '2',
				'3' => '3',
				'4' => '4',
				'5' => '5',
				'6' => '6',							
			),
			'std' => '3',
			'sub_desc' => esc_html__( 'Select number of column on Desktop Screen', 'flashmart' ),
		),

		array(
			'id' => 'product_col_medium',
			'type' => 'select',
			'title' => esc_html__('Product Listing column Medium Desktop', 'flashmart'),
			'options' => array(
				'2' => '2',
				'3' => '3',
				'4' => '4',	
				'5' => '5',
				'6' => '6',
			),
			'std' => '2',
			'sub_desc' => esc_html__( 'Select number of column on Medium Desktop Screen', 'flashmart' ),
		),

		array(
			'id' => 'product_col_sm',
			'type' => 'select',
			'title' => esc_html__('Product Listing column Tablet', 'flashmart'),
			'options' => array(
				'2' => '2',
				'3' => '3',
				'4' => '4',	
				'5' => '5',
				'6' => '6'
			),
			'std' => '2',
			'sub_desc' => esc_html__( 'Select number of column on Tablet Screen', 'flashmart' ),
		),

		array(
			'id' => 'sidebar_product',
			'type' => 'select',
			'title' => esc_html__('Sidebar Product Layout', 'flashmart'),
			'options' => array(
				''		=> esc_html__( 'Select Layout', 'flashmart' ),
				'left'	=> esc_html__( 'Left Sidebar', 'flashmart' ),
				'full' 	=> esc_html__( 'Full Layout', 'flashmart' ),		
				'right' => esc_html__( 'Right Sidebar', 'flashmart' )
			),
			'std' => 'left',
			'sub_desc' => esc_html__( 'Select style sidebar product', 'flashmart' ),
		),

		array(
			'id' => 'product_quickview',
			'title' => esc_html__( 'Quickview', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off Product Quickview', 'flashmart' ),
			'std' => '1'
		),

		array(
			'id' => 'product_listing_countdown',
			'title' => esc_html__( 'Enable Countdown', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off Product Countdown on product listing', 'flashmart' ),
			'std' => '1'
		),

		array(
			'id' => 'product_soldout',
			'title' => esc_html__( 'Product Sold Out', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off product sold out label', 'flashmart' ),
			'std' => '1'
		),


		array(
			'id' => 'product_number',
			'type' => 'text',
			'title' => esc_html__('Product Listing Number', 'flashmart'),
			'sub_desc' => esc_html__( 'Show number of product in listing product page.', 'flashmart' ),
			'std' => 12
		),

		array(
			'id' => 'newproduct_time',
			'title' => esc_html__( 'New Product', 'flashmart' ),
			'type' => 'number',
			'sub_desc' => '',
			'desc' => esc_html__( 'Set day for the new product label from the date publish product.', 'flashmart' ),
			'std' => '1'
		),

		array(
			'id' => 'info_typo1',
			'type' => 'info',
			'title' => esc_html__( 'Product Single Config', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'sidebar_product_detail',
			'type' => 'select',
			'title' => esc_html__('Sidebar Product Single Layout', 'flashmart'),
			'options' => array(
				'left'	=> esc_html__( 'Left Sidebar', 'flashmart' ),
				'full' 	=> esc_html__( 'Full Layout', 'flashmart' ),		
				'right' => esc_html__( 'Right Sidebar', 'flashmart' )
			),
			'std' => 'left',
			'sub_desc' => esc_html__( 'Select style sidebar product single', 'flashmart' ),
		),

		array(
			'id' => 'sticky_sidebar',
			'type' => 'checkbox',
			'title' => esc_html__('Active sticky Sidebar', 'flashmart'),
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off product sticky sidebar', 'flashmart' ),
			'std' => '0'// 1 = on | 0 = off
			),

		array(
			'id' => 'product_single_style',
			'type' => 'select',
			'title' => esc_html__('Product Detail Style', 'flashmart'),
			'options' => array(
				'default'	=> esc_html__( 'Default', 'flashmart' ),
				'style1' 	=> esc_html__( 'Full Width', 'flashmart' ),	
				'style2' 	=> esc_html__( 'Full Width With Accordion', 'flashmart' ),	
				'style3' 	=> esc_html__( 'Full Width With Accordion 1', 'flashmart' ),	
			),
			'std' => 'default',
			'sub_desc' => esc_html__( 'Select style for product single', 'flashmart' ),
		),

		array(
			'id' => 'product_single_thumbnail',
			'type' => 'select',
			'title' => esc_html__('Product Thumbnail Position', 'flashmart'),
			'options' => array(
				'bottom'	=> esc_html__( 'Bottom', 'flashmart' ),
				'left' 		=> esc_html__( 'Left', 'flashmart' ),	
				'right' 	=> esc_html__( 'Right', 'flashmart' ),	
				'top' 		=> esc_html__( 'Top', 'flashmart' ),					
			),
			'std' => 'bottom',
			'sub_desc' => esc_html__( 'Select style for product single thumbnail', 'flashmart' ),
		),		


		array(
			'id' => 'product_zoom',
			'title' => esc_html__( 'Product Zoom', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off image zoom when hover on single product', 'flashmart' ),
			'std' => '1'
		),

		array(
			'id' => 'product_brand',
			'title' => esc_html__( 'Enable Product Brand Image', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off product brand image show on single product.', 'flashmart' ),
			'std' => '1'
		),

		array(
			'id' => 'product_single_countdown',
			'title' => esc_html__( 'Enable Countdown Single', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off Product Countdown on product single', 'flashmart' ),
			'std' => '1'
		),

		array(
			'id' => 'product_single_buynow',
			'title' => esc_html__( 'Enable Buy Now Button', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => '',
			'desc' => esc_html__( 'Turn On/Off buy now button on product single and quickview', 'flashmart' ),
			'std' => '1'
		),
		
		array(
			'id' => 'info_typo1',
			'type' => 'info',
			'title' => esc_html__( 'Config For Product Categories Widget', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'product_number_item',
			'type' => 'text',
			'title' => esc_html__( 'Category Number Item Show', 'flashmart' ),
			'sub_desc' => esc_html__( 'Choose to number of item category that you want to show, leave 0 to show all category', 'flashmart' ),
			'std' => 8
		),	

		array(
			'id' => 'product_more_text',
			'type' => 'text',
			'title' => esc_html__( 'Category More Text', 'flashmart' ),
			'sub_desc' => esc_html__( 'Change more text on category product', 'flashmart' ),
			'std' => ''
		),

		array(
			'id' => 'product_less_text',
			'type' => 'text',
			'title' => esc_html__( 'Category Less Text', 'flashmart' ),
			'sub_desc' => esc_html__( 'Change less text on category product', 'flashmart' ),
			'std' => ''
		)	
	)
);		
$options[] = array(
	'title' => esc_html__('Typography', 'flashmart'),
	'desc' => wp_kses( __('<p class="description">Change the font style of your blog, custom with Google Font.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
			//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
			//You dont have to though, leave it flashmart for default.
	'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_151_edit.png',
			//Lets leave this as a flashmart section, no options just some intro text set above.
	'fields' => array(
		array(
			'id' => 'info_typo1',
			'type' => 'info',
			'title' => esc_html__( 'Global Typography', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'google_webfonts',
			'type' => 'google_webfonts',
			'title' => esc_html__('Use Google Webfont', 'flashmart'),
			'sub_desc' => esc_html__( 'Insert font style that you actually need on your webpage.', 'flashmart' ), 
			'std' => ''
		),

		array(
			'id' => 'webfonts_weight',
			'type' => 'multi_select',
			'sub_desc' => esc_html__( 'For weight, see Google Fonts to custom for each font style.', 'flashmart' ),
			'title' => esc_html__('Webfont Weight', 'flashmart'),
			'options' => array(
				'100' => '100',
				'200' => '200',
				'300' => '300',
				'400' => '400',
				'500' => '500',
				'600' => '600',
				'700' => '700',
				'800' => '800',
				'900' => '900'
			),
			'std' => ''
		),

		array(
			'id' => 'info_typo2',
			'type' => 'info',
			'title' => esc_html__( 'Header Tag Typography', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'header_tag_font',
			'type' => 'google_webfonts',
			'title' => esc_html__('Header Tag Font', 'flashmart'),
			'sub_desc' => esc_html__( 'Select custom font for header tag ( h1...h6 )', 'flashmart' ), 
			'std' => ''
		),

		array(
			'id' => 'info_typo2',
			'type' => 'info',
			'title' => esc_html__( 'Main Menu Typography', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'menu_font',
			'type' => 'google_webfonts',
			'title' => esc_html__('Main Menu Font', 'flashmart'),
			'sub_desc' => esc_html__( 'Select custom font for main menu', 'flashmart' ), 
			'std' => ''
		),

		array(
			'id' => 'info_typo2',
			'type' => 'info',
			'title' => esc_html__( 'Custom Typography', 'flashmart' ),
			'desc' => '',
			'class' => 'flashmart-opt-info'
		),

		array(
			'id' => 'custom_font',
			'type' => 'google_webfonts',
			'title' => esc_html__('Custom Font', 'flashmart'),
			'sub_desc' => esc_html__( 'Select custom font for custom class', 'flashmart' ), 
			'std' => ''
		),

		array(
			'id' => 'custom_font_class',
			'title' => esc_html__( 'Custom Font Class', 'flashmart' ),
			'type' => 'text',
			'sub_desc' => esc_html__( 'Put custom class to this field. Each class separated by commas.', 'flashmart' ),
			'desc' => '',
			'std' => '',
		),

	)
);

$options[] = array(
	'title' => __('Social', 'flashmart'),
	'desc' => wp_kses( __('<p class="description">This feature allow to you link to your social.</p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
		//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
		//You dont have to though, leave it blank for default.
	'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_222_share.png',
		//Lets leave this as a blank section, no options just some intro text set above.
	'fields' => array(
		array(
			'id' => 'social-share-fb',
			'title' => esc_html__( 'Facebook', 'flashmart' ),
			'type' => 'text',
			'sub_desc' => '',
			'desc' => '',
			'std' => '',
		),
		array(
			'id' => 'social-share-tw',
			'title' => esc_html__( 'Twitter', 'flashmart' ),
			'type' => 'text',
			'sub_desc' => '',
			'desc' => '',
			'std' => '',
		),
		array(
			'id' => 'social-share-tumblr',
			'title' => esc_html__( 'Tumblr', 'flashmart' ),
			'type' => 'text',
			'sub_desc' => '',
			'desc' => '',
			'std' => '',
		),
		array(
			'id' => 'social-share-in',
			'title' => esc_html__( 'Linkedin', 'flashmart' ),
			'type' => 'text',
			'sub_desc' => '',
			'desc' => '',
			'std' => '',
		),
		array(
			'id' => 'social-share-instagram',
			'title' => esc_html__( 'Instagram', 'flashmart' ),
			'type' => 'text',
			'sub_desc' => '',
			'desc' => '',
			'std' => '',
		),
		array(
			'id' => 'social-share-pi',
			'title' => esc_html__( 'Pinterest', 'flashmart' ),
			'type' => 'text',
			'sub_desc' => '',
			'desc' => '',
			'std' => '',
		)

	)
);

$options[] = array(
	'title' => esc_html__('Advanced', 'flashmart'),
	'desc' => wp_kses( __('<p class="description">Custom advanced with Cpanel, Widget advanced, Developer mode </p>', 'flashmart'), array( 'p' => array( 'class' => array() ) ) ),
			//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
			//You dont have to though, leave it flashmart for default.
	'icon' => FLASHMART_URL.'/admin/img/glyphicons/glyphicons_083_random.png',
			//Lets leave this as a flashmart section, no options just some intro text set above.
	'fields' => array(
		array(
			'id' => 'show_cpanel',
			'title' => esc_html__( 'Show cPanel', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => esc_html__( 'Turn on/off Cpanel', 'flashmart' ),
			'desc' => '',
			'std' => ''
		),

		array(
			'id' => 'widget-advanced',
			'title' => esc_html__('Widget Advanced', 'flashmart'),
			'type' => 'checkbox',
			'sub_desc' => esc_html__( 'Turn on/off Widget Advanced', 'flashmart' ),
			'desc' => '',
			'std' => '1'
		),					

		array(
			'id' => 'social_share',
			'title' => esc_html__( 'Social Share', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => esc_html__( 'Turn on/off social share', 'flashmart' ),
			'desc' => '',
			'std' => '1'
		),

		array(
			'id' => 'breadcrumb_active',
			'title' => esc_html__( 'Turn Off Breadcrumb', 'flashmart' ),
			'type' => 'checkbox',
			'sub_desc' => esc_html__( 'Turn off breadcumb on all page', 'flashmart' ),
			'desc' => '',
			'std' => '0'
		),

		array(
			'id' => 'back_active',
			'type' => 'checkbox',
			'title' => esc_html__('Back to top', 'flashmart'),
			'sub_desc' => '',
			'desc' => '',
						'std' => '1'// 1 = on | 0 = off
			),	

	)
);

$options_args = array();

	//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
$options_args['opt_name'] = SWG_THEME;

	//Custom menu title for options page - default is "Options"
$options_args['menu_title'] = esc_html__('Theme Options', 'flashmart');

	//Custom Page Title for options page - default is "Options"
$options_args['page_title'] = esc_html__('Flashmart Options ', 'flashmart');

	//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "flashmart_theme_options"
$options_args['page_slug'] = 'flashmart_theme_options';

	//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
$options_args['page_type'] = 'submenu';

	//custom page location - default 100 - must be unique or will override other items
$options_args['page_position'] = 27;
$swg_options = new SWG_Options( $options, $options_args );

return $options;
}
add_action( 'init', 'flashmart_Options_Setup', 0 );
endif; 


/*
** Define widget
*/
function flashmart_widget_setup_args(){
	$flashmart_widget_areas = array(
		
		array(
			'name' => esc_html__('Sidebar Left Blog', 'flashmart'),
			'id'   => 'left-blog',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget' => '</div></div>',
			'before_title' => '<div class="block-title-widget"><h2><span>',
			'after_title' => '</span></h2></div>'
		),
		array(
			'name' => esc_html__('Sidebar Right Blog', 'flashmart'),
			'id'   => 'right-blog',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget' => '</div></div>',
			'before_title' => '<div class="block-title-widget"><h2><span>',
			'after_title' => '</span></h2></div>'
		),

		array(
			'name' => esc_html__('Sidebar Above Product', 'flashmart'),
			'id'   => 'above-product',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget' => '</div></div>',
			'before_title' => '<div class="block-title-widget"><h2><span>',
			'after_title' => '</span></h2></div>'
		),
		
		array(
			'name' => esc_html__('Shop Categories', 'flashmart'),
			'id'   => 'shop-categories',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget' => '</div></div>',
			'before_title' => '<div class="block-title-widget"><h2><span>',
			'after_title' => '</span></h2></div>'
		),

		array(
			'name' => esc_html__('Sidebar Left Product', 'flashmart'),
			'id'   => 'left-product',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget' => '</div></div>',
			'before_title' => '<div class="block-title-widget"><h2><span>',
			'after_title' => '</span></h2></div>'
		),
		
		array(
			'name' => esc_html__('Sidebar Right Product', 'flashmart'),
			'id'   => 'right-product',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget' => '</div></div>',
			'before_title' => '<div class="block-title-widget"><h2><span>',
			'after_title' => '</span></h2></div>'
		),
		
		array(
			'name' => esc_html__('Sidebar Left Detail Product', 'flashmart'),
			'id'   => 'left-product-detail',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget' => '</div></div>',
			'before_title' => '<div class="block-title-widget"><h2><span>',
			'after_title' => '</span></h2></div>'
		),
		
		array(
			'name' => esc_html__('Sidebar Right Detail Product', 'flashmart'),
			'id'   => 'right-product-detail',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget' => '</div></div>',
			'before_title' => '<div class="block-title-widget"><h2><span>',
			'after_title' => '</span></h2></div>'
		),
		
		array(
			'name' => esc_html__('Sidebar Bottom Detail Product Sidebar', 'flashmart'),
			'id'   => 'bottom-detail-product',
			'before_widget' => '<div class="widget %1$s %2$s" data-scroll-reveal="enter bottom move 20px wait 0.2s"><div class="widget-inner">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h3>',
			'after_title'   => '</h3>'
		),

		array(
			'name' => esc_html__('Sidebar Bottom Detail Product Full', 'flashmart'),
			'id'   => 'bottom-detail-product2',
			'before_widget' => '<div class="widget %1$s %2$s" data-scroll-reveal="enter bottom move 20px wait 0.2s"><div class="widget-inner">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h3>',
			'after_title'   => '</h3>'
		),
		
		array(
				'name' => esc_html__('Bottom Detail Product Mobile', 'flashmart'),
				'id'   => 'bottom-detail-product-mobile',
				'before_widget' => '<div id="%1$s" class="widget %1$s %2$s" data-scroll-reveal="enter bottom move 20px wait 0.2s"><div class="widget-inner">',
				'after_widget'  => '</div></div>',
				'before_title'  => '<h3>',
				'after_title'   => '</h3>'
		),
		
		array(
			'name' => esc_html__('Filter Mobile', 'flashmart'),
			'id'   => 'filter-mobile',
			'before_widget' => '<div id="%1$s" class="widget %1$s %2$s" data-scroll-reveal="enter bottom move 20px wait 0.2s"><div class="widget-inner">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h3>',
			'after_title'   => '</h3>'
		),
		array(
			'name' => esc_html__('Widget Search', 'flashmart'),
			'id'   => 'search',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h3>',
			'after_title'   => '</h3>'
		),
		array(
			'name' => esc_html__('Widget Mobile Top', 'flashmart'),
			'id'   => 'top-mobile',
			'before_widget' => '<div class="widget %1$s %2$s"><div class="widget-inner">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h3>',
			'after_title'   => '</h3>'
		)
	);
return apply_filters( 'flashmart_widget_register', $flashmart_widget_areas );
}